@@ -8,6 +8,7 @@ import importlib
 from prompt_toolkit import prompt
 from prompt_toolkit.output.win32 import NoConsoleScreenBufferError
 from requests import get, post, put, delete
+from typing import Union
 
 if __name__ == "__main__":
     from utils import gitee
@@ -15,6 +16,7 @@ if __name__ == "__main__":
     from utils.exceptions import RepositoryNotFoundError, TableNotFoundError, RepositoryNotFound
     from utils.urlparse import URL
     from utils.crypto import CryptoHandler
+    from utils.utils import typeassert
     from config import __version__
 else:
     from .utils import gitee
@@ -22,6 +24,7 @@ else:
     from .utils.exceptions import RepositoryNotFoundError, TableNotFoundError, RepositoryNotFound
     from .utils.urlparse import URL
     from .utils.crypto import CryptoHandler
+    from .utils.utils import typeassert
     from .config import __version__
 
 class termios:
@@ -36,29 +39,32 @@ class objects:
     def all(self):
         return self.obj.all_tables()
     
-    def get(self, name=None, directly_load=True):
+    @typeassert
+    def get(self, name: str, directly_load: bool=True):
         if name in self.obj.repo.list_folder(path=""):
             return SqleeTable(name=name, repo=self.obj.repo, directly_load=directly_load)
         raise TableNotFoundError(name)
 
-    def create(self, name=None, namespace=None):
+    @typeassert
+    def create(self, name: str, namespace: Union[list, tuple]):
         return self.obj.create_table(name=name, namespace=namespace)
 
-    def delete(self, *args, **kwargs):
-        return self.obj.drop_table(*args, **kwargs)
+    @typeassert
+    def delete(self, name: str):
+        return self.obj.drop_table(name)
     
     def count(self):
         return len(self.obj.repo.list_folder(path="", detail=True))
 
     @property
-    def count(self):
+    def length(self):
         return len(self.obj.repo.list_folder(path="", detail=True))
 
 class SqleeRepository:
-    access_token = None
-    repo = None
-    owner = None
-    def __init__(self, access_token, repo, owner, auto_make=False):
+    access_token: str
+    repo: str
+    owner: str
+    def __init__(self, access_token, repo, owner, auto_make: bool=False):
         self.access_token = access_token
         if auto_make:
             gitee.make_repo(name=repo, user=owner, token=access_token)
@@ -71,8 +77,9 @@ class SqleeRepository:
         tables = [SqleeTable(name=data['name'], repo=self.repo) for data in datas if data['type'] == 'dir']
         return tables
 
-    def create_table(self, name=None, namespace=None):
-        if not namespace:
+    @typeassert
+    def create_table(self, name: str, namespace: Union[list, tuple]):
+        if not namespace or not name:
             raise ValueError("未提供足够的参数.")
         for value in ["data", "length", "update", "delete",
                       "namespace", "count", "sync", "repo"]:
@@ -82,10 +89,12 @@ class SqleeRepository:
         self.repo.upload_file(path=URL(name)/".namespace", content=json.dumps(namespace))
         return make
 
-    def drop_table(self, name=None):
+    @typeassert
+    def drop_table(self, name: str):
         return self.repo.drop_folder(path=name)
 
-    def clear(self, sure=False):
+    @typeassert
+    def clear(self, sure: bool=False):
         if not sure:
             confirm = input("你确定删除本数据库(同时删除云端数据)吗? (Y/N) ")
             if confirm == "Y" or confirm == "y":
@@ -99,7 +108,6 @@ class SqleeRepository:
             url = url,
             data = {"access_token": self.access_token}
         )
-        del self
         return True
     
     def interact(self):
@@ -141,16 +149,4 @@ class SqleeRepository:
             try:
                 exec(cmd)
             except:
-                traceback.print_exc()
-
-if __name__ == '__main__':
-    """t_s = Sqlee(
-        access_token="f8eca055b26c3e4c64176d4c9f66902b",
-        owner="freetbash",
-        repo="sqleedb",
-    )"""
-    db = SqleeRepository(
-        access_token = "1895956f770eb0e4d08013ee4b753203",
-        owner = "fu050409",
-        repo = "TEST_API",
-    )
+                traceback.print_exc()
\ No newline at end of file
