@@ -138,7 +138,7 @@ class table_objects:
     def filter(self, *args, **kwargs):
         """ Usage: filter(**namespace) """
         if len(kwargs) == 1 and self.obj.index in kwargs:
-            if not kwargs[self.obj.index] in self.obj.repo.list_file_int(path=self.obj.index):
+            if not str(kwargs[self.obj.index]) in self.obj.repo.list_file(path=self.obj.name):
                 print(ColumnNotFoundError(URL(self.obj.name) / kwargs[self.obj.index]))
                 return []
             return [SqleeColumn(
