@@ -25,4 +25,4 @@ class Model:
         except Exception:
             pass
 
-verify_django()
\ No newline at end of file
+settings = verify_django()
